@@ -22,8 +22,8 @@
         DashboardPage.pollForInfo(page);
         DashboardPage.startInterval(apiClient);
 
-        $(apiClient).on("websocketmessage", DashboardPage.onWebSocketMessage)
-            .on("websocketopen", DashboardPage.onWebSocketOpen);
+        Events.on(apiClient, 'websocketmessage', DashboardPage.onWebSocketMessage);
+        Events.on(apiClient, 'websocketopen', DashboardPage.onWebSocketOpen);
 
         DashboardPage.lastAppUpdateCheck = null;
         DashboardPage.lastPluginUpdateCheck = null;
@@ -53,7 +53,8 @@
         var apiClient = ApiClient;
 
         if (apiClient) {
-            $(apiClient).off("websocketmessage", DashboardPage.onWebSocketMessage).off("websocketopen", DashboardPage.onWebSocketConnectionChange).off("websocketerror", DashboardPage.onWebSocketConnectionChange).off("websocketclose", DashboardPage.onWebSocketConnectionChange);
+            Events.off(apiClient, 'websocketmessage', DashboardPage.onWebSocketMessage);
+            Events.off(apiClient, 'websocketopen', DashboardPage.onWebSocketOpen);
             DashboardPage.stopInterval(apiClient);
         }
 
@@ -296,7 +297,7 @@
 
             html += '<div class="' + className + '" id="' + rowId + '">';
 
-            html += '<div class="cardBox">';
+            html += '<div class="cardBox" style="box-shadow:0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12), 0 3px 1px -2px rgba(0, 0, 0, 0.2);margin:4px;">';
             html += '<div class="cardScalable">';
 
             html += '<div class="cardPadder"></div>';
@@ -329,22 +330,16 @@
 
             html += '</div>';
 
-            html += '<div class="sessionUserInfo">';
+            html += '<div class="sessionNowPlayingTime">' + DashboardPage.getSessionNowPlayingTime(session) + '</div>';
 
-            var userImage = DashboardPage.getUserImage(session);
-            if (userImage) {
-                html += '<div class="sessionUserImage" data-src="' + userImage + '">';
-                html += '<img src="' + userImage + '" />';
-            } else {
-                html += '<div class="sessionUserImage">';
-            }
-            html += '</div>';
+            html += '<div class="sessionNowPlayingStreamInfo">' + DashboardPage.getSessionNowPlayingStreamInfo(session) + '</div>';
 
-            html += '<div class="sessionUserName">';
-            html += DashboardPage.getUsersHtml(session);
-            html += '</div>';
+            //if (session.TranscodingInfo && session.TranscodingInfo.Framerate) {
 
-            html += '</div>';
+            //    html += '<div class="sessionTranscodingFramerate">' + session.TranscodingInfo.Framerate + ' fps</div>';
+            //} else {
+            //    html += '<div class="sessionTranscodingFramerate"></div>';
+            //}
 
             var nowPlayingName = DashboardPage.getNowPlayingName(session);
 
@@ -371,33 +366,33 @@
 
             html += '</div>';
 
-            html += '<div class="cardOverlayTarget">';
-
-            html += '<div class="sessionNowPlayingStreamInfo">' + DashboardPage.getSessionNowPlayingStreamInfo(session) + '</div>';
-            html += '<div class="sessionNowPlayingTime">' + DashboardPage.getSessionNowPlayingTime(session) + '</div>';
-
-            if (session.TranscodingInfo && session.TranscodingInfo.Framerate) {
-
-                html += '<div class="sessionTranscodingFramerate">' + session.TranscodingInfo.Framerate + ' fps</div>';
-            } else {
-                html += '<div class="sessionTranscodingFramerate"></div>';
-            }
-            html += '</div>';
-
             html += '</div>';
 
             // cardScalable
             html += '</div>';
 
+            html += '<div style="padding:1em;border-top:1px solid #eee;background:#fff;text-align:center;text-transform:uppercase;display:flex;align-items:center;justify-content:center;">';
+
+            var userImage = DashboardPage.getUserImage(session);
+            if (userImage) {
+                html += '<img style="border-radius:50px;margin-right:.5em;" src="' + userImage + '" />';
+            } else {
+                html += '<div style="height:24px;"></div>';
+            }
+
+            html += '<div class="sessionUserName">';
+            html += DashboardPage.getUsersHtml(session) || '&nbsp;';
+            html += '</div>';
+            html += '</div>';
+
             // cardBox
             html += '</div>';
 
             // card
             html += '</div>';
-
         }
 
-        parentElement.append(html).createSessionItemMenus().trigger('create');
+        parentElement.append(html);
 
         $('.deadSession', parentElement).remove();
     },
@@ -406,56 +401,61 @@
 
         var html = '';
 
-        html += '<div>';
+        //html += '<div>';
 
         if (session.TranscodingInfo && session.TranscodingInfo.IsAudioDirect && session.TranscodingInfo.IsVideoDirect) {
             html += Globalize.translate('LabelPlayMethodDirectStream');
         }
         else if (session.PlayState.PlayMethod == 'Transcode') {
             html += Globalize.translate('LabelPlayMethodTranscoding');
+
+            if (session.TranscodingInfo && session.TranscodingInfo.Framerate) {
+
+                html += ' - '+session.TranscodingInfo.Framerate + ' fps';
+            }
         }
         else if (session.PlayState.PlayMethod == 'DirectStream') {
-            html += Globalize.translate('LabelPlayMethodDirectStream');
+            html += Globalize.translate('LabelPlayMethodDirectPlay');
         }
         else if (session.PlayState.PlayMethod == 'DirectPlay') {
             html += Globalize.translate('LabelPlayMethodDirectPlay');
         }
 
-        html += '</div>';
+        //html += '</div>';
 
-        if (session.TranscodingInfo) {
+        //if (session.TranscodingInfo) {
 
-            html += '<br/>';
+        //    html += '<br/>';
 
-            var line = [];
+        //    var line = [];
 
-            if (session.TranscodingInfo.Container) {
+        //    if (session.TranscodingInfo.Container) {
 
-                line.push(session.TranscodingInfo.Container);
-            }
-            if (session.TranscodingInfo.Bitrate) {
+        //        line.push(session.TranscodingInfo.Container);
+        //    }
+        //    if (session.TranscodingInfo.Bitrate) {
 
-                if (session.TranscodingInfo.Bitrate > 1000000) {
-                    line.push((session.TranscodingInfo.Bitrate / 1000000).toFixed(1) + ' Mbps');
-                } else {
-                    line.push(Math.floor(session.TranscodingInfo.Bitrate / 1000) + ' kbps');
-                }
-            }
-            if (line.length) {
+        //        if (session.TranscodingInfo.Bitrate > 1000000) {
+        //            line.push((session.TranscodingInfo.Bitrate / 1000000).toFixed(1) + ' Mbps');
+        //        } else {
+        //            line.push(Math.floor(session.TranscodingInfo.Bitrate / 1000) + ' kbps');
+        //        }
+        //    }
+        //    if (line.length) {
 
-                html += '<div>' + line.join(' ') + '</div>';
-            }
+        //        html += '<div>' + line.join(' ') + '</div>';
+        //    }
 
-            if (session.TranscodingInfo.VideoCodec) {
+        //    if (session.TranscodingInfo.VideoCodec) {
 
-                html += '<div>' + Globalize.translate('LabelVideoCodec').replace('{0}', session.TranscodingInfo.VideoCodec) + '</div>';
-            }
-            if (session.TranscodingInfo.AudioCodec && session.TranscodingInfo.AudioCodec != session.TranscodingInfo.Container) {
+        //        html += '<div>' + Globalize.translate('LabelVideoCodec').replace('{0}', session.TranscodingInfo.VideoCodec) + '</div>';
+        //    }
+        //    if (session.TranscodingInfo.AudioCodec && session.TranscodingInfo.AudioCodec != session.TranscodingInfo.Container) {
 
-                html += '<div>' + Globalize.translate('LabelAudioCodec').replace('{0}', session.TranscodingInfo.AudioCodec) + '</div>';
-            }
+        //        html += '<div>' + Globalize.translate('LabelAudioCodec').replace('{0}', session.TranscodingInfo.AudioCodec) + '</div>';
+        //    }
 
-        }
+        //}
 
         return html;
     },
@@ -586,7 +586,7 @@
         $('.sessionNowPlayingStreamInfo', row).html(DashboardPage.getSessionNowPlayingStreamInfo(session));
         $('.sessionNowPlayingTime', row).html(DashboardPage.getSessionNowPlayingTime(session));
 
-        $('.sessionUserName', row).html(DashboardPage.getUsersHtml(session));
+        $('.sessionUserName', row).html(DashboardPage.getUsersHtml(session) || '&nbsp;');
 
         $('.sessionAppSecondaryText', row).html(DashboardPage.getAppSecondaryText(session));
 
@@ -970,104 +970,33 @@
 
     restart: function () {
 
-        Dashboard.confirm(Globalize.translate('MessageConfirmRestart'), Globalize.translate('HeaderRestart'), function (result) {
+        require(['confirm'], function (confirm) {
+
+            confirm(Globalize.translate('MessageConfirmRestart'), Globalize.translate('HeaderRestart')).then(function () {
 
-            if (result) {
                 $('#btnRestartServer').buttonEnabled(false);
                 $('#btnShutdown').buttonEnabled(false);
                 Dashboard.restartServer();
-            }
-
+            });
         });
     },
 
     shutdown: function () {
 
-        Dashboard.confirm(Globalize.translate('MessageConfirmShutdown'), Globalize.translate('HeaderShutdown'), function (result) {
+        require(['confirm'], function (confirm) {
+
+            confirm(Globalize.translate('MessageConfirmShutdown'), Globalize.translate('HeaderShutdown')).then(function () {
 
-            if (result) {
                 $('#btnRestartServer').buttonEnabled(false);
                 $('#btnShutdown').buttonEnabled(false);
                 ApiClient.shutdownServer();
-            }
-
+            });
         });
     }
 };
 
 $(document).on('pageshow', "#dashboardPage", DashboardPage.onPageShow).on('pagebeforehide', "#dashboardPage", DashboardPage.onPageHide);
 
-(function ($, document, window) {
-
-    var showOverlayTimeout;
-
-    function onHoverOut() {
-
-        if (showOverlayTimeout) {
-            clearTimeout(showOverlayTimeout);
-            showOverlayTimeout = null;
-        }
-
-        var elem = this.querySelector('.cardOverlayTarget');
-
-        if ($(elem).is(':visible')) {
-            require(["jquery", "velocity"], function ($, Velocity) {
-
-                Velocity.animate(elem, { "height": "0" },
-                {
-                    complete: function () {
-                        $(elem).hide();
-                    }
-                });
-            });
-        }
-    }
-
-    $.fn.createSessionItemMenus = function () {
-
-        function onShowTimerExpired(elem) {
-
-            if ($('.itemSelectionPanel:visible', elem).length) {
-                return;
-            }
-
-            var innerElem = $('.cardOverlayTarget', elem);
-
-            innerElem.show().each(function () {
-
-                this.style.height = 0;
-
-            }).animate({ "height": "100%" }, "fast");
-        }
-
-        function onHoverIn() {
-
-            if (showOverlayTimeout) {
-                clearTimeout(showOverlayTimeout);
-                showOverlayTimeout = null;
-            }
-
-            var elem = this;
-
-            showOverlayTimeout = setTimeout(function () {
-
-                onShowTimerExpired(elem);
-
-            }, 1000);
-        }
-
-        if (AppInfo.isTouchPreferred) {
-            /* browser with either Touch Events of Pointer Events
-               running on touch-capable device */
-            return this;
-        }
-
-        return this.off('mouseenter', '.playingSession', onHoverIn).off('mouseleave', '.playingSession', onHoverOut).on('mouseenter', '.playingSession', onHoverIn).on('mouseleave', '.playingSession', onHoverOut);
-    };
-
-})(jQuery, document, window);
-
-
 (function ($, document, window) {
 
     function getEntryHtml(entry) {
@@ -1195,7 +1124,8 @@ $(document).on('pageshow', "#dashboardPage", DashboardPage.onPageShow).on('pageb
             return;
         }
 
-        $(apiClient).on('websocketmessage', onSocketMessage).on('websocketopen', onSocketOpen);
+        Events.on(apiClient, 'websocketopen', onSocketOpen);
+        Events.on(apiClient, 'websocketmessage', onSocketMessage);
     }
 
     function startListening(apiClient) {
@@ -1239,7 +1169,8 @@ $(document).on('pageshow', "#dashboardPage", DashboardPage.onPageShow).on('pageb
         var apiClient = ApiClient;
 
         if (apiClient) {
-            $(apiClient).off('websocketopen', onSocketOpen).off('websocketmessage', onSocketOpen);
+            Events.off(apiClient, 'websocketopen', onSocketOpen);
+            Events.off(apiClient, 'websocketmessage', onSocketMessage);
 
             stopListening(apiClient);
         }
@@ -1267,7 +1198,7 @@ $(document).on('pageshow', "#dashboardPage", DashboardPage.onPageShow).on('pageb
 
 (function ($, document, window) {
 
-    var welcomeDismissValue = '11';
+    var welcomeDismissValue = '12';
     var welcomeTourKey = 'welcomeTour';
 
     function dismissWelcome(page, userId) {
@@ -1309,27 +1240,35 @@ $(document).on('pageshow', "#dashboardPage", DashboardPage.onPageShow).on('pageb
 
     function takeTour(page, userId) {
 
-        require(['swipebox'], function () {
+        require(['slideshow'], function () {
 
-            $.swipebox([
-                    { href: 'css/images/tour/dashboard/dashboard.png', title: Globalize.translate('DashboardTourDashboard') },
-                    { href: 'css/images/tour/dashboard/help.png', title: Globalize.translate('DashboardTourHelp') },
-                    { href: 'css/images/tour/dashboard/users.png', title: Globalize.translate('DashboardTourUsers') },
-                    { href: 'css/images/tour/dashboard/sync.png', title: Globalize.translate('DashboardTourSync') },
-                    { href: 'css/images/tour/dashboard/cinemamode.png', title: Globalize.translate('DashboardTourCinemaMode') },
-                    { href: 'css/images/tour/dashboard/chapters.png', title: Globalize.translate('DashboardTourChapters') },
-                    { href: 'css/images/tour/dashboard/subtitles.png', title: Globalize.translate('DashboardTourSubtitles') },
-                    { href: 'css/images/tour/dashboard/plugins.png', title: Globalize.translate('DashboardTourPlugins') },
-                    { href: 'css/images/tour/dashboard/notifications.png', title: Globalize.translate('DashboardTourNotifications') },
-                    { href: 'css/images/tour/dashboard/scheduledtasks.png', title: Globalize.translate('DashboardTourScheduledTasks') },
-                    { href: 'css/images/tour/dashboard/mobile.png', title: Globalize.translate('DashboardTourMobile') },
-                    { href: 'css/images/tour/enjoy.jpg', title: Globalize.translate('MessageEnjoyYourStay') }
-            ], {
-                afterClose: function () {
-                    dismissWelcome(page, userId);
-                    $('.welcomeMessage', page).hide();
-                },
-                hideBarsDelay: 30000
+            var slides = [
+                    { imageUrl: 'css/images/tour/dashboard/dashboard.png', title: Globalize.translate('DashboardTourDashboard') },
+                    { imageUrl: 'css/images/tour/dashboard/help.png', title: Globalize.translate('DashboardTourHelp') },
+                    { imageUrl: 'css/images/tour/dashboard/users.png', title: Globalize.translate('DashboardTourUsers') },
+                    { imageUrl: 'css/images/tour/dashboard/sync.png', title: Globalize.translate('DashboardTourSync') },
+                    { imageUrl: 'css/images/tour/dashboard/cinemamode.png', title: Globalize.translate('DashboardTourCinemaMode') },
+                    { imageUrl: 'css/images/tour/dashboard/chapters.png', title: Globalize.translate('DashboardTourChapters') },
+                    { imageUrl: 'css/images/tour/dashboard/subtitles.png', title: Globalize.translate('DashboardTourSubtitles') },
+                    { imageUrl: 'css/images/tour/dashboard/plugins.png', title: Globalize.translate('DashboardTourPlugins') },
+                    { imageUrl: 'css/images/tour/dashboard/notifications.png', title: Globalize.translate('DashboardTourNotifications') },
+                    { imageUrl: 'css/images/tour/dashboard/scheduledtasks.png', title: Globalize.translate('DashboardTourScheduledTasks') },
+                    { imageUrl: 'css/images/tour/dashboard/mobile.png', title: Globalize.translate('DashboardTourMobile') },
+                    { imageUrl: 'css/images/tour/enjoy.jpg', title: Globalize.translate('MessageEnjoyYourStay') }
+            ];
+
+            require(['slideshow'], function (slideshow) {
+
+                var newSlideShow = new slideshow({
+                    slides: slides,
+                    interactive: true,
+                    loop: false
+                });
+
+                newSlideShow.show();
+
+                dismissWelcome(page, userId);
+                $('.welcomeMessage', page).hide();
             });
         });
     }
@@ -1369,7 +1308,7 @@ $(document).on('pageshow', "#dashboardPage", DashboardPage.onPageShow).on('pageb
 
                 if (!pluginSecurityInfo.IsMBSupporter && AppInfo.enableSupporterMembership) {
 
-                    var html = '<div class="supporterPromotion"><a class="clearLink" href="http://emby.media/premiere" target="_blank" style="font-size:14px;"><paper-button raised class="block" style="text-transform:none;background-color:#52B54B;color:#fff;"><div>' + Globalize.translate('HeaderSupportTheTeam') + '</div><div style="font-weight:normal;margin-top:5px;">' + Globalize.translate('TextEnjoyBonusFeatures') + '</div></paper-button></a></div>';
+                    var html = '<div class="supporterPromotion"><a class="clearLink" href="http://emby.media/premiere" target="_blank"><paper-button raised class="block" style="text-transform:none;background-color:#52B54B;color:#fff;"><div>' + Globalize.translate('HeaderSupportTheTeam') + '</div><div style="font-weight:normal;margin-top:5px;">' + Globalize.translate('TextEnjoyBonusFeatures') + '</div></paper-button></a></div>';
 
                     $('.content-primary', page).append(html);
                 }
